@@ -25,7 +25,7 @@ def full_rebuild(skip_pauses: bool = False, patch: bool = True):
         full_tourney_ids = load_json_from_file("Phase 1 Ids.json")
 
     # Phase 2. Updates sources list
-    new_sources_file_path, patch_sources_file_path = generate_new_sources_files(full_tourney_ids)
+    new_sources_file_path, patch_sources_file_path = generate_new_sources_files(full_tourney_ids, skip_redownload=True)
     print("Phase 2 done.")
 
     # Phase 3. Rebuild/patch/skip
@@ -62,7 +62,6 @@ if __name__ == '__main__':
     dotenv.load_dotenv()
     logging.basicConfig(level=logging.DEBUG)
 
-    # _phase_3(join(SLAPP_DATA_FOLDER, 'sources_patch.yaml'), "patch")
+    # full_rebuild(skip_pauses=True, patch=True)
     update_sources_with_placements()
     update_sources_with_skills(clear_current_skills=True)
-    # full_rebuild(skip_pauses=True, patch=False)
