@@ -1,7 +1,9 @@
-from typing import Dict, Union, List, Tuple, Optional
+import logging
+from typing import Dict, Union, List, Tuple, Optional, Iterable
 from uuid import UUID
 
 from slapp_py.core_classes.bracket import Bracket
+from slapp_py.core_classes.division import Division
 from slapp_py.core_classes.player import Player
 from slapp_py.core_classes.skill import Skill
 from slapp_py.core_classes.team import Team
@@ -120,6 +122,9 @@ class SlappResponseObject:
     def get_teams_for_player(self, p: Player) -> List[Team]:
         return [self.get_team(t_uuid) for t_uuid in p.teams]
 
+    def get_best_team_for_player(self, p: Player) -> Team:
+        return self.get_best_team_by_div([self.get_team(t_uuid) for t_uuid in p.teams])
+
     def get_team_skills(self, team_guid: Union[UUID, str], include_ex_players: bool = True) -> Dict[Player, Skill]:
         """
         Return Player objects with their skills for the specified team id,
@@ -128,18 +133,50 @@ class SlappResponseObject:
         players = self.get_players_in_team(team_guid, include_ex_players)
         return {player: player.skill for player in players}
 
-    def get_first_placements(self, p: Player) -> List[str]:
+    def get_sources_for_player(self, p: Player) -> Dict[str, List[Bracket]]:
+        """
+        Gets the sources for the specified player, keyed by source id.
+        """
+        return self.placements_for_players.get(p.guid.__str__(), {})
+
+    def get_source_names_for_player(self, p: Player) -> List[str]:
+        """
+        Gets the sources for the specified player in name form.
+        """
         result = []
-        if p.guid.__str__() in self.placements_for_players:
-            sources = self.placements_for_players[p.guid.__str__()]
-            for source_id in sources:
-                brackets = self.placements_for_players[p.guid.__str__()][source_id]
-                for bracket in brackets:
-                    if 1 in bracket.placements.players_by_placement:
-                        first_place_ids = [player_id.__str__() for player_id in
-                                           bracket.placements.players_by_placement[1]]
-                        if p.guid.__str__() in first_place_ids:
-                            result.append(bracket.name + ' in ' + attempt_link_source(self.sources[source_id]))
+        for source in p.sources:
+            from slapp_py.core_classes.builtins import BuiltinSource
+            if source == BuiltinSource.guid:
+                result.append("(builtin)")
+            else:
+                name = self.sources.get(source.__str__(), None)
+                if not name:
+                    logging.error(f"Source was not specified in JSON: {source}")
+                else:
+                    result.append(name)
+        return result
+
+    def get_brackets_for_player(self, p: Player, source_id: str) -> List[Bracket]:
+        """
+        Gets the brackets for the specified player for the source specified.
+        """
+        return self.placements_for_players.get(p.guid.__str__(), {}).get(source_id.__str__(), [])
+
+    def get_first_placements(self, p: Player) -> List[str]:
+        """
+        Gets a list of displayed text in form {bracket.name} + ' in ' + {attempt_link_source(self.sources[source_id])}
+        where the specified player has come first.
+        """
+        result = []
+        sources = self.get_sources_for_player(p)
+        for source_id in sources:
+            brackets = self.get_brackets_for_player(p, source_id)
+            for bracket in brackets:
+                if 1 in bracket.placements.players_by_placement:
+                    first_place_ids = [player_id.__str__() for player_id in
+                                       bracket.placements.players_by_placement[1]]
+                    if p.guid.__str__() in first_place_ids:
+                        result.append(bracket.name + ' in ' + attempt_link_source(self.sources[source_id]))
 
         return result
 
@@ -210,3 +247,21 @@ class SlappResponseObject:
     @staticmethod
     def placement_is_winning_low_ink(placement: Tuple[int, str, str]):
         return placement and placement[0] == 1 and ("Top Cut" in placement[1] or "Alpha" in placement[1])
+
+    @staticmethod
+    def get_best_team_by_div(known_teams: Iterable[Team]) -> Optional[Team]:
+        """
+        Calculate the best team by div in an iterable of teams.
+        """
+        if not known_teams:
+            return None
+
+        best_team = None
+        current_highest_div = Division()
+        for team in known_teams:
+            highest_div = team.get_best_div()
+            if highest_div < current_highest_div:
+                current_highest_div = highest_div
+                best_team = team
+
+        return best_team
